@@ -5,13 +5,13 @@
 # https://github.com/pypa/warehouse/blob/master/warehouse/__about__.py
 
 __name__ = "blis"
-__version__ = "1.0.1"
+__version__ = "1.2.1"
 __summary__ = (
     "The Blis BLAS-like linear algebra library, as a self-contained C-extension."
 )
 __uri__ = "https://github.com/explosion/cython-blis"
-__author__ = "Explosion"
-__email__ = "contact@explosion.ai"
-__license__ = "BSD-3-Clause"
+__author__ = "Matthew Honnibal"
+__email__ = "matt@explosion.ai"
+__license__ = "BSD"
 __title__ = "blis"
 __release__ = True
